<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\MAN\Services;


class ConfigPortaisController {
    protected $configPortaisServices;
    protected $fileUploaderService;
    
   public function __construct (Services\ConfigPortaisServices $configPortaisServices, $parameterBag, Manager $dataSourceManager, Services\FileUploaderService $fileUploaderService){
       $this->configPortaisServices     = $configPortaisServices;
        $this->parameterBag             = $parameterBag;
        $this->dataSourceManager        = $dataSourceManager;
        $this->fileUploaderService      = $fileUploaderService;
    }
    
    // pager digital
    // find
    public function findConfigPortais(DTO\Request $request, DTO\Response $response) {
        $conditions = $request->getParameters()['row'];
        $params = array();
        
        $params['NRORG'] = $conditions[0]['value'];
        $params['CDFILIAL'] = $conditions[1]['value'];
        
        $query = $this->configPortaisServices->findPager($params);

        $response->addDataSet(new DataSet("findConfigPortais", $query));
    }
    
    // save pager digital
    public function savePagerDigital(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();

        $params =  array();
        $params['NRORG'] = $row['NRORG'];


        $params['CDURLPGEDIG'] = $row['CDURLPGEDIG'];
        $this->configPortaisServices->saveGerparamgeral($params);
        
        $params['CDFILIAL'] = $row['CDFILIAL'];
        $params['IDUSAPGEDIG'] = $row['IDUSAPGEDIG'];
        if(is_array($row['BS64IMGPGEDIG'])){
            $params['BS64IMGPGEDIG'] = $row['BS64IMGPGEDIG'][0]['b64File'];
        }else{
            $params['BS64IMGPGEDIG'] = $row['BS64IMGPGEDIG'];
        }
        $params['IDUSATMPMEDPGE'] = $row['IDUSATMPMEDPGE'];
        $params['DSENDPGEDIG'] = $row['DSENDPGEDIG'];
        $params['IDMSGATRASOPGE'] = $row['IDMSGATRASOPGE'];
        $this->configPortaisServices->saveParavend($params);
    }
    
    // site cashback
    //find
    public function findSiteCashback(DTO\Request $request, DTO\Response $response){
        $conditions['NRORG'] = $request->getParameters()['NRORG'];

        $query = $this->configPortaisServices->findSiteCashback($conditions);
        
        $response->addDataSet(new DataSet("findSiteCashback", $query));
    }
    
    // save cashback
    public function saveCasback(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        if(isset($row['LOGOPRINCIPAL']) && is_array($row['LOGOPRINCIPAL'])){
            $row['LOGOPRINCIPAL'] = $row['LOGOPRINCIPAL'][0]['b64File'];
        }else if(isset($row['LOGOPRINCIPAL'])){
            $row['LOGOPRINCIPAL'] = $row['LOGOPRINCIPAL'];
        }
        else{
            $row['LOGOPRINCIPAL'] = NULL;
        }
        
         if(isset($row['LOGORODAPE']) && is_array($row['LOGORODAPE'])){
            $row['LOGORODAPE'] = $row['LOGORODAPE'][0]['b64File'];
        }else if(isset($row['LOGORODAPE'])){
            $row['LOGORODAPE'] = $row['LOGORODAPE'];
        }else{
            $row['LOGORODAPE'] = NULL;
        }
        
        $params = [
            "CORPRIMARIA"                   => isset($row['CORPRIMARIA']) ? $row['CORPRIMARIA'] : null,
            "CORSECUNDARIA"                 => isset($row['CORSECUNDARIA']) ? $row['CORSECUNDARIA'] : null,
            "CORBOTAO"                      => isset($row['CORBOTAO']) ? $row['CORBOTAO'] : null,
            "LOGOPRINCIPAL"                 => $row['LOGOPRINCIPAL'],
            "LOGORODAPE"                    => $row['LOGORODAPE'],
            "CORRODAPE"                     => isset($row['CORRODAPE']) ? $row['CORRODAPE'] : null,
            "TEXTOSUCESSO"                  => isset($row['TEXTOSUCESSO']) ? $row['TEXTOSUCESSO'] : null,
            "TEXTOJACADASTRADO"             => isset($row['TEXTOJACADASTRADO']) ? $row['TEXTOJACADASTRADO'] : null,
            "TEXTOVENDASNAOENCONTRADO"      => isset($row['TEXTOVENDASNAOENCONTRADO']) ? $row['TEXTOVENDASNAOENCONTRADO'] : null,
            "APPPROPRIO"                    => isset($row['APPPROPRIO']) ? $row['APPPROPRIO'] : null,
            "LINKPLAYSTORE"                 => isset($row['LINKPLAYSTORE']) ? $row['LINKPLAYSTORE'] : null,
            "LINKAPPSTORE"                  => isset($row['LINKAPPSTORE']) ? $row['LINKAPPSTORE'] : null,
            "ENVIOSMS"                      => isset($row['ENVIOSMS']) ? $row['ENVIOSMS'] : null,
            "URLSMS"                        => isset($row['URLSMS']) ? $row['URLSMS'] : null,
            "TOKENTELE"                     => isset($row['TOKENTELE']) ? $row['TOKENTELE'] : null,
            "NMLOJASMS"                     => isset($row['NMLOJASMS']) ? $row['NMLOJASMS'] : null,
            "MENSASALDOSMS"                 => isset($row['MENSASALDOSMS']) ? $row['MENSASALDOSMS'] : null,
            "MENSACREDGERA"                 => isset($row['MENSACREDGERA']) ? $row['MENSACREDGERA'] : null,
            "MENSACADCONSUMIDOR"            => isset($row['MENSACADCONSUMIDOR']) ? $row['MENSACADCONSUMIDOR'] : null,
            "NRORG"                         => $row['NRORG']
        ];
        
       if(isset($row['DTINCLUSAO'])){
            $params['NRORGULTATU'] = $row['NRORG'];
            $params['CDOPERULTATU'] = 1;
            
            $this->configPortaisServices->updateCashback($params);
        }else{
            $params['IDATIVO'] = 'S';
            $params['NRORGINCLUSAO'] = $row['NRORG'];
            $params['CDOPERINCLUSAO'] = '1';
            
            $this->configPortaisServices->insertCashback($params);
        }
    }

}


?>